import React, { useState, useRef } from 'react';

import { SingleMessage, BulkMessage } from './Messages';

const Message = () => {
    const [isSelectOpen, setIsSelectOpen] = useState(false);
    const [activeTab, setActiveTab] = useState('single');
    const fileInputRef = useRef(null);

    const handleFocus = () => {
        setIsSelectOpen(true);
    };

    const handleBlur = () => {
        setIsSelectOpen(false);
    };

    const handleClick = async () => {
        console.log('Make SMS Demo');
    };

    const handleImageUpload = (event) => {
        const file = event.target.files[0];
        if (file && (file.type === 'image/jpeg' || file.type === 'image/png' || file.type === 'image/jpg')) {
            console.log('File uploaded:', file.name); // Handle the file upload
        } else {
            alert('Please upload a valid image file (JPG, JPEG).');
        }
    };

    return (
        <div>
            {/* Tab buttons */}
            <div>
                <button
                    onClick={() => setActiveTab('single')}
                    style={activeTab === 'single' ? styles.tabButton : styles.tabInactiveButton}
                >
                    Single Message
                </button>
                <button
                    onClick={() => setActiveTab('bulk')}
                    style={activeTab === 'bulk' ? styles.tabButton : styles.tabInactiveButton}
                >
                    Bulk Message
                </button>
            </div>

            {/* Conditional content based on active tab */}
            {activeTab === 'single' && <SingleMessage 
                isSelectOpen={isSelectOpen} 
                handleFocus={handleFocus} 
                handleBlur={handleBlur} 
                handleClick={handleClick} 
            />}
            {activeTab === 'bulk' && <BulkMessage 
                isSelectOpen={isSelectOpen} 
                handleFocus={handleFocus} 
                handleBlur={handleBlur} 
                handleClick={handleClick} 
                handleImageUpload={handleImageUpload} 
                fileInputRef={fileInputRef} 
            />}
        </div>
    );
};


export default Message;

const styles = {
    loadingOverlay: {
        position: 'fixed',
        top: 0,
        left: 0,
        width: '100%',
        height: '100%',
        backgroundColor: 'rgba(0, 0, 0, 0.5)',
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        zIndex: 9999
    },
    spinner: {
        width: '50px',
        height: '50px',
        border: '5px solid #f3f3f3',
        borderTop: '5px solid #0542CC',
        borderRadius: '50%',
        animation: 'spin 1s linear infinite'
    },
    selectWrapper: {
        position: 'relative',
        marginTop: '0',
    },
    select: {
        width: '100%',
        paddingRight: '30px',
        flex: 1,
        fontSize: '16px',
        outline: 'none',
    },
    chevronIcon: {
        position: 'absolute',
        right: '10px',
        top: '50%',
        transform: 'translateY(-50%)',
        pointerEvents: 'none',
    },
    remainingQuota: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center',
        marginTop: '4px',
    },
    quotaText: {
        fontSize: '40px',
        color: '#0542cc',
        fontWeight: '600',
    },
    timesText: {
        marginLeft: '8px',
        verticalAlign: 'super',
        fontSize: '20px',
    },
    tabButton: {
        display: 'inline-block',
        padding: '10px 20px',
        fontSize: '16px',
        cursor: 'pointer',
        backgroundColor: '#0542cc',
        color: '#fff',
        border: 'none',
        marginRight: '10px',
        borderRadius: '7px'
    },
    tabInactiveButton: {
        display: 'inline-block',
        padding: '10px 20px',
        fontSize: '16px',
        cursor: 'pointer',
        backgroundColor: '#fff',
        color: '#0542cc',
        border: '1px solid #0542cc',
        marginRight: '10px',
        borderRadius: '7px'
    },
    submitButton: {
        marginLeft: 'auto',
        marginTop: '1rem',
        textAlign: 'start',
        position: 'relative',
        zIndex: 1,
    },
    uploadArea: {
        backgroundColor: '#e6f2ff',
        height: '250px',
        cursor: 'pointer',
        paddingTop: '22px',
        display: 'flex',
        flexDirection: 'column',
        justifyContent: 'center',
        alignItems: 'center',
        border: '1px solid #ced4da',
        borderRadius: '0.25rem',
    },
    uploadIcon: {
        fontSize: '40px',
        color: '#0542cc',
        marginBottom: '7px',
    },
    uploadText: {
        color: '#1f2d3d',
        fontWeight: '400',
        fontSize: '16px',
        lineHeight: '13px',
    },
    uploadError: {
        color: 'red',
    },
    waMessagePreview: {
        backgroundColor: '#F8F9FA',
        padding: '15px',
        borderRadius: '8px',
        border: '1px solid #dcdcdc',
        marginBottom: '20px',
    },
    preview: {
        marginTop: '20px',
    },
    // Bulk Message
    uploadArea: {
        backgroundColor: '#e6f2ff',
        height: '250px',
        cursor: 'pointer',
        marginTop: '1rem',
        paddingTop: '22px',
        display: 'flex',
        flexDirection: 'column',
        justifyContent: 'center',
        alignItems: 'center',
        border: '1px solid #ced4da',
        borderRadius: '0.25rem',
    },
    uploadIcon: {
        fontSize: '40px',
        color: '#0542cc',
        marginBottom: '7px',
    },
    uploadText: {
        color: '#1f2d3d',
        fontWeight: '400',
        fontSize: '12px',
        lineHeight: '13px',
    },
    fileWrapper: {
        backgroundColor: '#fff',
        border: '0.2px solid gray',
        padding: '15px 0 0 17px',
        borderRadius: '5px',
        position: 'relative',
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'space-between',
        height: '65px',
    },        
    imageIcon: {
        color: '#0542cc',
        fontSize: '24px',
        marginBottom: '1rem'
    },
    closeIcon: {
        color: 'red',
        cursor: 'pointer',
        fontSize: '26px',
        marginRight: '1rem',
        marginBottom: '1rem'
    },
    customLabel: {
        fontWeight: 600,
        fontSize: '14px',
        color: '#212529'
    },
    submitButton: {
        marginTop: '20px',
    },
};
